from setuptools import setup, find_packages

setup(
    name='ai-scraper-toolkit',
    version='0.0.2',
    description='Scrpers ,crawls and cleans the data it finds',
    author='Harsh Avinash',
    author_email='harsh.avinash.official@gmail.com',
    packages=find_packages(),
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
    ],
)



